==> nextcloud-23.0.3.tgz: nextcloud/apps/survey_client/l10n/lv.js <==
OC.L10N.register(
    "survey_client",
    {
    "An error occurred while sending your report." : "Radās kļūda sūtot Jūsu atskaiti",
    "Database environment <em>(type, version, database size)</em>" : "Datu bāzes vide <em>(tips, versija, datu bāzes izmērs)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Šefrēšanas informācija <em>(iespējota?, kāds ir noklusētais modulis)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Koplietojumu skaits <em>(pēc tipa un piekļuvju uzstādījumiem)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP vide <em>(versija, atmiņas limits, max. izpildes laiks, max. datnes izmērs)</em>",
    "Usage survey" : "Izmantojamības aptauja",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Vēlaties mums palīdzēt uzlabot Nextcloud, anonīmi sniedzot datus par Jūsu iestatījumiem un izmantojamību? Jūs varat šo iespēju atspējot jebkurā brīdī administratora uzstādījumos.",
    "Not now" : "Ne tagad",
    "Send usage" : "Nosūtīt izmantojamību",
    "Never" : "Nekad",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Jūs varat mums palīdzēt uzlabot Nextcloud, sniedzot datus par Jūsu iestatījumiem un izmantojamību.",
    "Send new report now" : "Nosūtīt jaunu atskaiti tagad",
    "Send usage survey monthly" : "Sūtīt izmantojamības aptauju ik mēnesi",
    "Data to send" : "Dati sūtīšanai",
    "Last report" : "Pēdējā atskaite"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-28.0.9.tgz: nextcloud/apps/survey_client/l10n/lv.js <==
OC.L10N.register(
    "survey_client",
    {
    "An error occurred while sending your report." : "Radās kļūda sūtot Jūsu atskaiti",
    "Database environment <em>(type, version, database size)</em>" : "Datubāzes vide <em>(veids, versija, datubāzes izmērs)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Šefrēšanas informācija <em>(iespējota?, kāds ir noklusētais modulis)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Koplietojumu skaits <em>(pēc tipa un piekļuvju uzstādījumiem)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP vide <em>(versija, atmiņas limits, max. izpildes laiks, max. datnes izmērs)</em>",
    "Usage survey" : "Izmantojamības aptauja",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Vēlaties mums palīdzēt uzlabot Nextcloud, anonīmi sniedzot datus par Jūsu iestatījumiem un izmantojamību? Jūs varat šo iespēju atspējot jebkurā brīdī administratora uzstādījumos.",
    "Not now" : "Ne tagad",
    "Send usage" : "Nosūtīt izmantojamību",
    "Never" : "Nekad",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Jūs varat mums palīdzēt uzlabot Nextcloud, sniedzot datus par Jūsu iestatījumiem un izmantojamību.",
    "Send new report now" : "Nosūtīt jaunu atskaiti tagad",
    "Send usage survey monthly" : "Sūtīt izmantojamības aptauju ik mēnesi",
    "Data to send" : "Dati sūtīšanai",
    "Last report" : "Pēdējā atskaite"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
